Method: JavaClass::Classpath::Factory#full_classpath

Defined in:
lib/javaclass/classpath/factory.rb

#full_classpath(javahome, path = nil, cp = CompositeClasspath.new) ⇒ Object

Parse the given path variable path and return a chain of class path elements together with javahome if any.



29
30
31
32
33
# File 'lib/javaclass/classpath/factory.rb', line 29

def full_classpath(javahome, path=nil, cp=CompositeClasspath.new)
  cp.add_element(JavaHomeClasspath.new(javahome)) if javahome
  cp = classpath(path, cp) if path
  cp
end